==> kmyfirewall-trinity-14.1.2.tar.xz: kmyfirewall-trinity-14.1.2/kmyfirewall/ruleoptionplugins/interface_option/kmfruleoptioneditinterface.cpp <==
//
// C++ Implementation: kmfruleoptioneditiip
//
// Description:
//
//
// Author: Christian Hubinger <chubinger@irrsinnig.org>, (C) 2004
//
// Copyright: See COPYING file that comes with this distribution
//
//
#include "kmfruleoptioneditinterface.h"


// TQt includes
#include <tqstring.h>

// KDE includes
#include <kdebug.h>
#include <tdelocale.h>

// Project includes
#include "../../core/iptrule.h"
#include "../../core/kmfruleeditinterface.h"
#include "kmfruleeditorinterface.h"

namespace KMF {
KMFRuleOptionEditorInterface::KMFRuleOptionEditorInterface(TQObject *parent, const char *name)
		: KMFRuleOptionEditInterface(parent, name) {
	kdDebug() <<"KMFRuleOptionEditorInterface::KMFRuleOptionEditorInterface(TQObject *parent, const char *name)" << endl;
	kdDebug() << "Parent has Type: " << parent->className()  << endl;
	
	m_edit = new KMFRuleEditorInterface( 0 , "Edit", 0 );
	m_edit->hide();

/*	connect( m_edit,TQ_SIGNAL(sigAddRuleOpt(TQString*, TQPtrList< TQString >* ) ), 
		this,TQ_SLOT( slotAddRuleOption(TQString*, TQPtrList< TQString >* ) ) );
	connect( m_edit,TQ_SIGNAL(sigAddTargetOpt(TQString*, TQPtrList< TQString >* ) ), 
		this,TQ_SLOT( slotAddTargetOption(TQString*, TQPtrList< TQString >* ) ) );*/
	connect( m_edit,TQ_SIGNAL(sigHideMe() ), 
		this,TQ_SLOT( slotShowOverview() ) );
}
KMFRuleOptionEditorInterface::~KMFRuleOptionEditorInterface() {}

void KMFRuleOptionEditorInterface::slotShowOverview() {
	if ( KMFRuleEditInterface* ruleedit = dynamic_cast<KMFRuleEditInterface*> ( parent() ) ) {
		ruleedit->showOverview();
	} else {
		kdDebug() << "KMFRuleOptionEditCustom::slotShowOverview(): parent() not of type KMFRuleEditInterface" << endl;
	}
}

const TQString& KMFRuleOptionEditorInterface::optionEditName() const {
	return *( new TQString( i18n("Interface Option") ) );
}
const TQString& KMFRuleOptionEditorInterface::description() const {
	return *( new TQString( i18n("This plugin manages the Interface based options of iptables.") ) );
}

void KMFRuleOptionEditorInterface::loadRule( IPTRule* rule ) {
	if ( !rule ) {
		kdDebug() << "KMFRuleOptionEditorInterface::loadRule( IPTRule* rule ) - rule == 0" << endl;
		return;
	}
	
	m_edit->loadRule( rule );
	m_rule = rule;

}

TQWidget* KMFRuleOptionEditorInterface::editWidget() {
	if ( ! m_edit ) {
		kdDebug() << "KMFRuleOptionEditorInterface::editWidget() - m_edit == 0" << endl;
		return 0;
	}
	return m_edit;
}





// It's usually safe to leave the factory code alone.. with the
// notable exception of the TDEAboutData data
#include <tdeaboutdata.h>
#include <tdelocale.h>

// TDEInstance* KMFRuleOptionEditorInterfaceFactory::s_instance = 0L;
// TDEAboutData* KMFRuleOptionEditorInterfaceFactory::s_about = 0L;

KMFRuleOptionEditorInterfaceFactory::KMFRuleOptionEditorInterfaceFactory( TQObject* parent, const char* name )
		: KLibFactory( parent, name ) {
// 	s_instance = new TDEInstance( "KMFRuleOptionEditorInterfaceFactory" );
}

TQObject* KMFRuleOptionEditorInterfaceFactory::createObject( TQObject* parent, const char* name,
        const char*, const TQStringList & ) {
	TQObject * obj = new KMFRuleOptionEditorInterface( parent, name );
	emit objectCreated( obj );
	return obj;
}


// TDEInstance* KMFRuleOptionEditorInterfaceFactory::instance() {
// 	if ( !s_instance ) {
// 		s_instance = new TDEInstance( "KMFRuleOptionEditorInterfaceFactory" );
// 	}
// 	return s_instance;
// }

extern "C" {
	void* init_libkmfruleoptionedit_interface() {
		return new KMFRuleOptionEditorInterfaceFactory;
	}
}

}


#include "kmfruleoptioneditinterface.moc"

==> kmyfirewall-trinity-14.1.4.tar.xz: kmyfirewall-trinity-14.1.4/kmyfirewall/ruleoptionplugins/interface_option/kmfruleoptioneditinterface.cpp <==
//
// C++ Implementation: kmfruleoptioneditiip
//
// Description:
//
//
// Author: Christian Hubinger <chubinger@irrsinnig.org>, (C) 2004
//
// Copyright: See COPYING file that comes with this distribution
//
//
#include "kmfruleoptioneditinterface.h"


// TQt includes
#include <tqstring.h>

// KDE includes
#include <kdebug.h>
#include <tdelocale.h>

// Project includes
#include "../../core/iptrule.h"
#include "../../core/kmfruleeditinterface.h"
#include "kmfruleeditorinterface.h"

namespace KMF {
KMFRuleOptionEditorInterface::KMFRuleOptionEditorInterface(TQObject *parent, const char *name)
		: KMFRuleOptionEditInterface(parent, name) {
	kdDebug() <<"KMFRuleOptionEditorInterface::KMFRuleOptionEditorInterface(TQObject *parent, const char *name)" << endl;
	kdDebug() << "Parent has Type: " << parent->className()  << endl;
	
	m_edit = new KMFRuleEditorInterface( 0 , "Edit", 0 );
	m_edit->hide();

/*	connect( m_edit,TQ_SIGNAL(sigAddRuleOpt(TQString*, TQPtrList< TQString >* ) ), 
		this,TQ_SLOT( slotAddRuleOption(TQString*, TQPtrList< TQString >* ) ) );
	connect( m_edit,TQ_SIGNAL(sigAddTargetOpt(TQString*, TQPtrList< TQString >* ) ), 
		this,TQ_SLOT( slotAddTargetOption(TQString*, TQPtrList< TQString >* ) ) );*/
	connect( m_edit,TQ_SIGNAL(sigHideMe() ), 
		this,TQ_SLOT( slotShowOverview() ) );
}
KMFRuleOptionEditorInterface::~KMFRuleOptionEditorInterface() {}

void KMFRuleOptionEditorInterface::slotShowOverview() {
	if ( KMFRuleEditInterface* ruleedit = dynamic_cast<KMFRuleEditInterface*> ( parent() ) ) {
		ruleedit->showOverview();
	} else {
		kdDebug() << "KMFRuleOptionEditCustom::slotShowOverview(): parent() not of type KMFRuleEditInterface" << endl;
	}
}

const TQString& KMFRuleOptionEditorInterface::optionEditName() const {
	return *( new TQString( i18n("Interface Option") ) );
}
const TQString& KMFRuleOptionEditorInterface::description() const {
	return *( new TQString( i18n("This plugin manages the Interface based options of iptables.") ) );
}

void KMFRuleOptionEditorInterface::loadRule( IPTRule* rule ) {
	if ( !rule ) {
		kdDebug() << "KMFRuleOptionEditorInterface::loadRule( IPTRule* rule ) - rule == 0" << endl;
		return;
	}
	
	m_edit->loadRule( rule );
	m_rule = rule;

}

TQWidget* KMFRuleOptionEditorInterface::editWidget() {
	if ( ! m_edit ) {
		kdDebug() << "KMFRuleOptionEditorInterface::editWidget() - m_edit == 0" << endl;
		return 0;
	}
	return m_edit;
}





// It's usually safe to leave the factory code alone.. with the
// notable exception of the TDEAboutData data
#include <tdeaboutdata.h>
#include <tdelocale.h>

// TDEInstance* KMFRuleOptionEditorInterfaceFactory::s_instance = 0L;
// TDEAboutData* KMFRuleOptionEditorInterfaceFactory::s_about = 0L;

KMFRuleOptionEditorInterfaceFactory::KMFRuleOptionEditorInterfaceFactory( TQObject* parent, const char* name )
		: KLibFactory( parent, name ) {
// 	s_instance = new TDEInstance( "KMFRuleOptionEditorInterfaceFactory" );
}

TQObject* KMFRuleOptionEditorInterfaceFactory::createObject( TQObject* parent, const char* name,
        const char*, const TQStringList & ) {
	TQObject * obj = new KMFRuleOptionEditorInterface( parent, name );
	emit objectCreated( obj );
	return obj;
}


// TDEInstance* KMFRuleOptionEditorInterfaceFactory::instance() {
// 	if ( !s_instance ) {
// 		s_instance = new TDEInstance( "KMFRuleOptionEditorInterfaceFactory" );
// 	}
// 	return s_instance;
// }

extern "C" {
	TDE_EXPORT void* init_libkmfruleoptionedit_interface() {
		return new KMFRuleOptionEditorInterfaceFactory;
	}
}

}


#include "kmfruleoptioneditinterface.moc"
